Curvlinops
=================================

Installation
------------

.. code:: bash

  pip install curvlinops-for-pytorch


.. toctree::
	:maxdepth: 2
	:caption: Getting started

	usage


.. toctree::
	:maxdepth: 2
	:caption: Curvlinops

	linops
	basic_usage/index

.. toctree::
	:caption: Internals

	internals
